require 'studio_game/player'

module StudioGame

	describe Player do

		before do
			@initial_health = 150
			@player = Player.new("larry", @initial_health)
		end

		it "has a capitalized name" do
			expect(@player.name).to eq("Larry")
		end

		it "has an initial health" do
			expect(@player.health).to eq(150)
		end

		it "has a string representation" do
			expect(@player.to_s).to eq("Larry has 150HP & 0 Treasure pts for a total of 150GP")
		end

		it "increases health by 10 when wooted" do
			@player.woot
			@player.health

			expect(@player.health).to eq(160)

		end

		it "decreases health by 10 when blammed" do
			@player.blam
			@player.health

			expect(@player.health).to eq(140)
		end

		context "with a health greater than 100" do
			before do
				@player = Player.new("larry", 150)
			end

			it "is strong" do
				expect(@player.strong?).to eq(true)    
			end

		end

		context "with a health less than or eq to 100" do
			before do
				@player = Player.new("larry", 100)
			end

			it "is wimpy" do
				# expect(@player.strong?).to eq(false)
				expect(@player).not_to be_strong    
			end

		end

		context "in a collection of players" do

			before do
				@player1 = Player.new("moe", 100)
				@player2 = Player.new("larry", 200)
				@player3 = Player.new("curly", 300)

				@players = [@player1, @player2, @player3]
			end


			it "is sorted by decreasing score" do
			expect(@players.sort).to eq([@player3, @player2, @player1])
			end

		end

		it "computes points as the sum of all treasure and health points" do

			@player.found_treasure(Treasure.new(:hammer, 50))
	  		@player.found_treasure(Treasure.new(:hammer, 50))

	  		expect(@player.score).to eq(250)
		end

		it "returns each of players treasure objects" do
			@player.found_treasure(Treasure.new(:skillet, 100))
			@player.found_treasure(Treasure.new(:skillet, 100))
			@player.found_treasure(Treasure.new(:hammer, 50))
			@player.found_treasure(Treasure.new(:bottle, 5))
			@player.found_treasure(Treasure.new(:bottle, 5))
			@player.found_treasure(Treasure.new(:bottle, 5))
			@player.found_treasure(Treasure.new(:bottle, 5))
			@player.found_treasure(Treasure.new(:bottle, 5))

	  		yielded = []
	  		@player.each_found_treasure do |treasure|
	  			yielded << treasure
	  		end

	  		expect(yielded).to eq([
	  			Treasure.new(:skillet, 200),
				Treasure.new(:hammer, 50),
				Treasure.new(:bottle, 25)
	  		])

	  	end

	  	it "creates a player from csv" do

	  		player = Player.from_csv("larry,150")

	  		expect(player.name).to eq("Larry")
	  		expect(player.health).to eq(150)
	  	end


	end

end




















